Class: SsnValidator::Engine

Inherits:
Rails::Engine
  • Object
show all
Defined in:
lib/ssn_validator/engine.rb

Overview

making this an engine gives us the rake task to copy the migrations to your application as well as the rake tasks defined in this gem in your application